require 'test_helper'

class BlogControllerTest < ActionDispatch::IntegrationTest  
  test "can't visit create blog form if not logged in" do
    get new_blog_path
    assert_redirected_to root_path
  end

  test "can visit create blog form if logged in" do
    post login_path(login: {username: "user_one", password: "password1"})
    get new_blog_path
    assert_response :success
  end

  test "can't create new blog if not logged in" do
    post new_blog_path(blog: {title: "My new blog",
                              slogan: "Just another blog"
                             })
    assert_redirected_to root_path
  end

  test "can create new blog if logged in" do
    post login_path(login: {username: "user_one", password: "password1"})
    post new_blog_path(blog: {title: "My new blog",
                              slogan: "Just another blog"
                             })
    assert_response :success
  end

  test "can't update blog if not logged in" do
    patch update_blog_path(blog_id: blogs(:two).id)
    assert_redirected_to root_path
  end

  test "can't update blog that belongs to another user" do
    old_blog_title = blogs(:two).title
    post login_path(login: {username: "user_one", password: "password1"})
    patch update_blog_path(blog_id: blogs(:two).id,
                           blog: {title: "new title"})
    assert_redirected_to root_path
    assert_equal old_blog_title, Blog.find(blogs(:two).id).title
  end

  test "can't update blog with invalid parameters" do
    old_blog_title = blogs(:one).title
    post login_path(login: {username: "user_one", password: "password1"})
    patch update_blog_path(blog_id: blogs(:one).id,
                           blog: {title: "new title", slogan: nil})
    assert_response :success
    assert_equal old_blog_title, Blog.find(blogs(:one).id).title
  end

  test "can update blog" do
    post login_path(login: {username: "user_one", password: "password1"})
    patch update_blog_path(blog_id: blogs(:one).id, blog: {title: "new title"})
    assert_redirected_to dashboard_path
    assert_equal "new title", Blog.find(blogs(:one).id).title
  end

  test "search returns 200 with missing param" do
    get search_path
    assert_response :success
  end
  
  test "search returns 200 with empty string" do
    get search_path(q: "")
    assert_response :success
  end
  
  test "search returns 200 with search string" do
    get search_path(q: "ruby on rails")
    assert_response :success
  end

  test "search title matches search string" do
    get search_path(q: "ruby on rails")
    assert_response :success
    assert_select "title", 'Search Results for "ruby on rails"'
  end

  test "can render blog when img_url is invalid" do
    get blog_path(blog_name: blogs(:imgless).urlName)
    assert_response :success
  end

  test "footer is missing when disabled in config" do
    Rails.configuration.pressr.footer = nil
    get root_path
    assert_select "div.main-footer", false
  end

  test "footer is missing when set to blank string" do
    Rails.configuration.pressr.footer = ""
    get root_path
    assert_select "div.main-footer", false
  end

  test "footer is set to config value when set" do
    Rails.configuration.pressr.footer = "This is a sample footer"
    get root_path
    assert_select "div.main-footer" do
      assert_select "div.main-footer-inner",
                    "This is a sample footer"
    end
  end
end
