require 'test_helper'

class CommentsControllerTest < ActionDispatch::IntegrationTest
  test "can't create comment when logged out" do
    latest_comment = Comment.last.id
    post comment_path(blog_name: blogs(:one).urlName,
                      post_id: posts(:one).id,
                      comment: {body: "Good post!"})
    assert_response :forbidden
    assert_equal latest_comment, Comment.last.id
  end

  test "can create comment when logged in" do
    latest_comment = Comment.last.id
    post login_path(login: {username: "user_one",
                            password: "password1"})
    post comment_path(blog_name: blogs(:one).urlName,
                      post_id: posts(:one).id,
                      comment: {body: "Good post!"})
    assert_redirected_to post_path(post_id: posts(:one).id,
                                   blog_name: blogs(:one).urlName)
    assert_not_equal latest_comment, Comment.last.id
    assert_equal "Good post!", Comment.last.body
  end
  
  test "can't delete comment when logged out" do
    c = comments(:one)
    delete delete_comment_path(id: c.id)
    assert_response :forbidden
    assert_equal false, Comment.find(c.id).deleted
  end

  test "can't delete someone else's comment when logged in as user" do
    post login_path(login: {username: "user_two",
                            password: "password2"})
    c = comments(:one)
    delete delete_comment_path(id: c.id)
    assert_response :forbidden
    assert_equal false, Comment.find(c.id).deleted
  end
  
  test "can delete comment when logged in" do
    post login_path(login: {username: "user_one",
                            password: "password1"})
    c = comments(:one)
    delete delete_comment_path(id: c.id)
    assert_redirected_to post_path(post_id: c.post.id,
                                   blog_name: blogs(:one).urlName)
    assert_equal true, Comment.find(c.id).deleted
  end

  test "can delete someone else's comment when logged in as admin" do
    post login_path(login: {username: "user_admin",
                            password: "admin_password"})
    c = comments(:one)
    delete delete_comment_path(id: c.id)
    assert_redirected_to post_path(post_id: c.post.id,
                                   blog_name: blogs(:one).urlName)
    assert_equal true, Comment.find(c.id).deleted
  end

  test "deleting non-existent comment returns 403" do
    post login_path(login: {username: "user_one",
                            password: "password1"})
    delete delete_comment_path(id: 0)
    assert_response :forbidden
  end

  test "user can delete comment on their post" do
    post login_path(login: {username: "user_one",
                            password: "password1"})
    c = comments(:two)
    delete delete_comment_path(id: c.id)
    assert_redirected_to post_path(post_id: c.post.id,
                                   blog_name: blogs(:one).urlName)
    assert_equal true, Comment.find(c.id).deleted
  end
end
