require 'test_helper'

class BlogTest < ActiveSupport::TestCase
  test "can't set bg with invalid colour(doesn't start with #)" do
    b = blogs(:one)
    old_color = b.bg_color
    b.bg = '1234567'
    b.save
    assert_equal ["Background color is invalid"], b.errors[:bg]
    assert_equal old_color, Blog.find(blogs(:one).id).bg_color
  end

  test "can't set bg with invalid colour(too many digits)" do
    b = blogs(:one)
    old_color = b.bg_color
    b.bg = '#1234567'
    b.save
    assert_equal ["Background color is invalid"], b.errors[:bg]
    assert_equal old_color, Blog.find(blogs(:one).id).bg_color    
  end

  test "can't set bg with invalid colour(not valid hex)" do
    b = blogs(:one)
    old_color = b.bg_color
    b.bg = '#EEFFAZ'
    b.save
    assert_equal ["Background color is invalid"], b.errors[:bg]
    assert_equal old_color, Blog.find(blogs(:one).id).bg_color
  end

  test "can set bg with valid colour" do
    b = blogs(:one)
    b.bg = '#AABBCC'
    b.save
    assert_equal [], b.errors[:bg]
    assert_equal 11189196, Blog.find(blogs(:one).id).bg_color
  end

  test "can't set fg with invalid colour(doesn't start with #)" do
    b = blogs(:one)
    old_color = b.fg_color
    b.fg = '1234567'
    b.save
    assert_equal ["Foreground color is invalid"], b.errors[:fg]
    assert_equal old_color, Blog.find(blogs(:one).id).fg_color
  end

  test "can't set fg with invalid colour(too many digits)" do
    b = blogs(:one)
    old_color = b.fg_color
    b.fg = '#1234567'
    b.save
    assert_equal ["Foreground color is invalid"], b.errors[:fg]
    assert_equal old_color, Blog.find(blogs(:one).id).fg_color
  end

  test "can't set fg with invalid colour(not valid hex)" do
    b = blogs(:one)
    old_color = b.fg_color
    b.fg = '#EEFFAZ'
    b.save
    assert_equal ["Foreground color is invalid"], b.errors[:fg]
    assert_equal old_color, Blog.find(blogs(:one).id).fg_color
  end

  test "can set fg with valid colour" do
    b = blogs(:one)
    b.fg = '#AABBCC'
    b.save
    assert_equal [], b.errors[:fg]
    assert_equal 11189196, Blog.find(blogs(:one).id).fg_color
  end

  test "bg returns nil when background colour is nil" do
    #Can't create blog with nil bg because it violates the not-null constraint
    assert_nil Blog.new.bg
  end

  test "bg returns colour when background colour is not nil" do
    assert_equal '#0001C8', blogs(:two).bg
  end

  test "fg returns nil when foreground colour is nil" do
    assert_nil Blog.new.fg
  end

  test "fg returns colour when foreground colour is not nil" do
    assert_equal '#000315', blogs(:two).fg
  end

  test "can_edit returns false if blog has no owner" do
    assert_equal false, blogs(:ownerless).can_edit(nil)
  end

  test "can_edit returns false if nil is passed to func" do
    assert_equal false, blogs(:one).can_edit(nil)
  end

  test "can_edit returns false if user passed cannot edit" do
    assert_equal false, blogs(:one).can_edit(users(:two))
  end

  test "can_edit returns true if user passed can edit" do
    assert_equal true, blogs(:one).can_edit(users(:one))
  end
end
