require 'test_helper'

class CategoryTest < ActiveSupport::TestCase
  test "duplicate post/category pairings only returns one post" do
    p = posts(:one)
    c = categories(:one)
    p.categories << c
    p.categories << c
    assert_equal 1, c.posts.count
  end

  test "can't create category with duplicate name" do
    c = categories(:one)
    c2 = Category.new
    c2.name = c.name
    c2.blog_id = c.blog_id
    assert_not c2.save
    assert_equal [[:name, "has already been taken"],
                  [:path, "has already been taken"]],
                 c2.errors.uniq
  end

  test "can't create category with duplicate path" do
    c = categories(:one)
    c2 = Category.new
    c2.name = c.name + "!"
    c2.blog_id = c.blog_id
    assert_not c2.save
    assert_equal [[:path, "has already been taken"]],
                 c2.errors.uniq
  end

  test "can't create category with short name" do
    c = Category.new
    c.name = "hi"
    c.blog = blogs(:one)
    assert_not c.save
    assert_equal ["Name is too short (minimum is 3 characters)"],
                 c.errors.full_messages
  end

  test "can't create category with long name" do
    c = Category.new
    c.name = "1234567890123456789012345678901"
    c.blog = blogs(:one)
    assert_not c.save
    assert_equal ["Name is too long (maximum is 30 characters)"],
                 c.errors.full_messages
  end

  test "can't create category with no name" do
    c = Category.new
    c.blog = blogs(:one)
    assert_not c.save
    assert_equal ["Name is too short (minimum is 3 characters)"],
                 c.errors.full_messages
  end

  test "can create category otherwise" do
    c = Category.new
    c.blog = blogs(:one)
    c.name = "new category"
    assert c.save
    assert_equal "new-category", c.path
  end
end
